@@ -21,12 +21,14 @@ test_files = [
     (test_file, ),
     (xm13_path / 'Xray_mosaic_v13.xrm', ),
     (xm13_path / 'Xray_mosaic_v13_interrupt.xrm', ),
+    (xm13_path / 'Xray_mosaic_7x7_v13.xrm', ),
     (xm13_path / 'Xray_single_v13.xrm', ),
     (xm13_path / 'tomo_v13_full.txrm', ),
     (xm13_path / 'tomo_v13_full_noref.txrm', ),
     (xm13_path / 'tomo_v13_interrupt.txrm', ),
     (xm13_path / 'VLM_mosaic_v13.xrm', ),
     (xm13_path / 'VLM_mosaic_v13_interrupt.xrm', ),
+    (xm13_path / 'VLM_grid_mosaic_large_v13.xrm', ),
     (xm10_path / '12_Tomo_F4D_Area1_noref.txrm', ),
     (xm10_path / 'VLM_mosaic.xrm', ),
     (xm10_path / 'test_tomo2_e3C_full.txrm', ),
